// WARNING: Please don't edit this file. It was generated by C++/WinRT v2.0.250303.1

#pragma once
#ifndef WINRT_Windows_Management_Deployment_1_H
#define WINRT_Windows_Management_Deployment_1_H
#include "winrt/impl/Windows.Management.Deployment.0.h"
WINRT_EXPORT namespace winrt::Windows::Management::Deployment
{
    struct WINRT_IMPL_EMPTY_BASES IAddPackageOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAddPackageOptions>
    {
        IAddPackageOptions(std::nullptr_t = nullptr) noexcept {}
        IAddPackageOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAddPackageOptions2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAddPackageOptions2>
    {
        IAddPackageOptions2(std::nullptr_t = nullptr) noexcept {}
        IAddPackageOptions2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppInstallerManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppInstallerManager>
    {
        IAppInstallerManager(std::nullptr_t = nullptr) noexcept {}
        IAppInstallerManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAppInstallerManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAppInstallerManagerStatics>
    {
        IAppInstallerManagerStatics(std::nullptr_t = nullptr) noexcept {}
        IAppInstallerManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAutoUpdateSettingsOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAutoUpdateSettingsOptions>
    {
        IAutoUpdateSettingsOptions(std::nullptr_t = nullptr) noexcept {}
        IAutoUpdateSettingsOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IAutoUpdateSettingsOptionsStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IAutoUpdateSettingsOptionsStatics>
    {
        IAutoUpdateSettingsOptionsStatics(std::nullptr_t = nullptr) noexcept {}
        IAutoUpdateSettingsOptionsStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICreateSharedPackageContainerOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICreateSharedPackageContainerOptions>
    {
        ICreateSharedPackageContainerOptions(std::nullptr_t = nullptr) noexcept {}
        ICreateSharedPackageContainerOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ICreateSharedPackageContainerResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ICreateSharedPackageContainerResult>
    {
        ICreateSharedPackageContainerResult(std::nullptr_t = nullptr) noexcept {}
        ICreateSharedPackageContainerResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDeleteSharedPackageContainerOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDeleteSharedPackageContainerOptions>
    {
        IDeleteSharedPackageContainerOptions(std::nullptr_t = nullptr) noexcept {}
        IDeleteSharedPackageContainerOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDeleteSharedPackageContainerResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDeleteSharedPackageContainerResult>
    {
        IDeleteSharedPackageContainerResult(std::nullptr_t = nullptr) noexcept {}
        IDeleteSharedPackageContainerResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDeploymentResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDeploymentResult>
    {
        IDeploymentResult(std::nullptr_t = nullptr) noexcept {}
        IDeploymentResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IDeploymentResult2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IDeploymentResult2>
    {
        IDeploymentResult2(std::nullptr_t = nullptr) noexcept {}
        IDeploymentResult2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IFindSharedPackageContainerOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IFindSharedPackageContainerOptions>
    {
        IFindSharedPackageContainerOptions(std::nullptr_t = nullptr) noexcept {}
        IFindSharedPackageContainerOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageAllUserProvisioningOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageAllUserProvisioningOptions>
    {
        IPackageAllUserProvisioningOptions(std::nullptr_t = nullptr) noexcept {}
        IPackageAllUserProvisioningOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageAllUserProvisioningOptions2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageAllUserProvisioningOptions2>
    {
        IPackageAllUserProvisioningOptions2(std::nullptr_t = nullptr) noexcept {}
        IPackageAllUserProvisioningOptions2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager>
    {
        IPackageManager(std::nullptr_t = nullptr) noexcept {}
        IPackageManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager10 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager10>
    {
        IPackageManager10(std::nullptr_t = nullptr) noexcept {}
        IPackageManager10(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager11 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager11>
    {
        IPackageManager11(std::nullptr_t = nullptr) noexcept {}
        IPackageManager11(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager12 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager12>
    {
        IPackageManager12(std::nullptr_t = nullptr) noexcept {}
        IPackageManager12(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager2>
    {
        IPackageManager2(std::nullptr_t = nullptr) noexcept {}
        IPackageManager2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager3 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager3>
    {
        IPackageManager3(std::nullptr_t = nullptr) noexcept {}
        IPackageManager3(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager4 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager4>
    {
        IPackageManager4(std::nullptr_t = nullptr) noexcept {}
        IPackageManager4(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager5 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager5>
    {
        IPackageManager5(std::nullptr_t = nullptr) noexcept {}
        IPackageManager5(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager6 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager6>
    {
        IPackageManager6(std::nullptr_t = nullptr) noexcept {}
        IPackageManager6(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager7 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager7>
    {
        IPackageManager7(std::nullptr_t = nullptr) noexcept {}
        IPackageManager7(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager8 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager8>
    {
        IPackageManager8(std::nullptr_t = nullptr) noexcept {}
        IPackageManager8(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManager9 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManager9>
    {
        IPackageManager9(std::nullptr_t = nullptr) noexcept {}
        IPackageManager9(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageManagerDebugSettings :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageManagerDebugSettings>
    {
        IPackageManagerDebugSettings(std::nullptr_t = nullptr) noexcept {}
        IPackageManagerDebugSettings(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageUserInformation :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageUserInformation>
    {
        IPackageUserInformation(std::nullptr_t = nullptr) noexcept {}
        IPackageUserInformation(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageVolume :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageVolume>
    {
        IPackageVolume(std::nullptr_t = nullptr) noexcept {}
        IPackageVolume(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IPackageVolume2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IPackageVolume2>
    {
        IPackageVolume2(std::nullptr_t = nullptr) noexcept {}
        IPackageVolume2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRegisterPackageOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRegisterPackageOptions>
    {
        IRegisterPackageOptions(std::nullptr_t = nullptr) noexcept {}
        IRegisterPackageOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRegisterPackageOptions2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRegisterPackageOptions2>
    {
        IRegisterPackageOptions2(std::nullptr_t = nullptr) noexcept {}
        IRegisterPackageOptions2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRemovePackageOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRemovePackageOptions>
    {
        IRemovePackageOptions(std::nullptr_t = nullptr) noexcept {}
        IRemovePackageOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IRemovePackageOptions2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IRemovePackageOptions2>
    {
        IRemovePackageOptions2(std::nullptr_t = nullptr) noexcept {}
        IRemovePackageOptions2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISharedPackageContainer :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISharedPackageContainer>
    {
        ISharedPackageContainer(std::nullptr_t = nullptr) noexcept {}
        ISharedPackageContainer(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISharedPackageContainerManager :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISharedPackageContainerManager>
    {
        ISharedPackageContainerManager(std::nullptr_t = nullptr) noexcept {}
        ISharedPackageContainerManager(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISharedPackageContainerManagerStatics :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISharedPackageContainerManagerStatics>
    {
        ISharedPackageContainerManagerStatics(std::nullptr_t = nullptr) noexcept {}
        ISharedPackageContainerManagerStatics(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISharedPackageContainerMember :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISharedPackageContainerMember>
    {
        ISharedPackageContainerMember(std::nullptr_t = nullptr) noexcept {}
        ISharedPackageContainerMember(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES ISharedPackageContainerMemberFactory :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<ISharedPackageContainerMemberFactory>
    {
        ISharedPackageContainerMemberFactory(std::nullptr_t = nullptr) noexcept {}
        ISharedPackageContainerMemberFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IStagePackageOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IStagePackageOptions>
    {
        IStagePackageOptions(std::nullptr_t = nullptr) noexcept {}
        IStagePackageOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IStagePackageOptions2 :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IStagePackageOptions2>
    {
        IStagePackageOptions2(std::nullptr_t = nullptr) noexcept {}
        IStagePackageOptions2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IUpdateSharedPackageContainerOptions :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IUpdateSharedPackageContainerOptions>
    {
        IUpdateSharedPackageContainerOptions(std::nullptr_t = nullptr) noexcept {}
        IUpdateSharedPackageContainerOptions(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
    struct WINRT_IMPL_EMPTY_BASES IUpdateSharedPackageContainerResult :
        winrt::Windows::Foundation::IInspectable,
        impl::consume_t<IUpdateSharedPackageContainerResult>
    {
        IUpdateSharedPackageContainerResult(std::nullptr_t = nullptr) noexcept {}
        IUpdateSharedPackageContainerResult(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
    };
}
#endif
